#####################################################################
# cmmucl.tcl - Console version of mmucl.
#
# Copyright (C) 1997-1998 Mark Patton
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#####################################################################

source [file join $env(MMUCL_DIR) lib mmucl.tcl]
source [file join $env(MMUCL_DIR) lib term.tcl]

namespace eval mmucl {
    array set Mmucl {
	cfg,echo            1
	cfg,echo_color      yellow
	cfg,hist_min        3
	cfg,keep_line       0
    }
}

proc mmucl::display {str} {
    variable Mmucl

    term::restore_pos
    puts -nonewline $str
    term::save_pos
    term::goto_rowcol $Mmucl(lines) [expr {$::term::term(point) + 1}]

    return
}

# Make split screen
proc mmucl::MCterm_init {} {
    variable Mmucl
    
    set Mmucl(lines) [term::num_rows]

    term::reset
    term::erase_screen
    term::scroll_region 1 [expr {$Mmucl(lines) - 2}]
    term::goto_rowcol [expr {$Mmucl(lines) - 2}] 1
    term::save_pos

    term::goto_rowcol [expr {$Mmucl(lines) - 1}] 1
    puts "-----"
    
    term::cbreak on

    return
}

proc mmucl::meta_parse {input} {
    variable Mmucl

    term::erase_toeol
    
    if {$Mmucl(cfg,keep_line)} {
	puts -nonewline \n[MCcolor $input bg_blue]
	set ::term::term(clearonhit) 1
    } else {
	term::endline
    }

    if {$Mmucl(cfg,echo)} {
	MCecho [MCcolor $input $Mmucl(cfg,echo_color)]
    }

    MCparse $input

    if {[string length $input] >= $Mmucl(cfg,hist_min)} {
    	history add $input
    }

    return
}

proc mmucl::MChelp {{subject ""}} {
    exec info (mmucl)$subject <@stdin >@stdout
    MCterm_init
}


rename exit _exit
proc exit {} {
    term::reset
    term::cbreak off
    _exit
}

fconfigure stdin -buffering none
fconfigure stdout -buffering none

mmucl::MCterm_init
mmucl::init

# Accept input from the console.
fileevent stdin readable {
    term::handle_input mmucl::meta_parse
}

# Enter the event loop.
vwait forever
